==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+60"/>
        <source>&amp;Command Line</source>
        <translation>&amp;C コマンドライン</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translation>コマンドライン</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translation type="obsolete">無効な座標 &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>不明なコマンドまたは無効な座標もしくは値: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>数値が&apos;%1&apos;として入力されました</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>座標が&apos;%1&apos; (絶対座標) or &apos;%2&apos; (相対座標) or &apos;%3&apos; (極座標) or &apos;%4&apos; (相対極座標)として入力されました</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>数値/座標のフォーマットをアプリケーション設定で変更できます。</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>ロックされたまたは不可視な画層のエンティティを描画、修正しようとしています。</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translation type="obsolete">ロックされたまたは不可視な画層のエンティティを描画、修正しようとしています。</translation>
    </message>
    <message>
        <location line="-317"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Invalid value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>無効な座標または距離 &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Info</source>
        <translation>情報</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translation>座標</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translation>ヒストリサイズ:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>ダイアログとして警告を表示</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>ダイアログとして情報を表示</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+60"/>
        <source>&amp;Command Line</source>
        <translation>&amp;C コマンドライン</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translation>コマンドライン</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translation type="obsolete">無効な座標 &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>不明なコマンドまたは無効な座標もしくは値: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>数値が&apos;%1&apos;として入力されました</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>座標が&apos;%1&apos; (絶対座標) or &apos;%2&apos; (相対座標) or &apos;%3&apos; (極座標) or &apos;%4&apos; (相対極座標)として入力されました</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>数値/座標のフォーマットをアプリケーション設定で変更できます。</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>ロックされたまたは不可視な画層のエンティティを描画、修正しようとしています。</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translation type="obsolete">ロックされたまたは不可視な画層のエンティティを描画、修正しようとしています。</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+218"/>
        <source>Invalid value:</source>
        <translation>不正な値:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>無効な座標または距離 &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Info</source>
        <translation>情報</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Expression</source>
        <translation>評価式</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translation>座標</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translation>ヒストリサイズ:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>ダイアログとして警告を表示</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>ダイアログとして情報を表示</translation>
    </message>
</context>
</TS>
